import os
from distutils.command.build import build

from django.core import management
from setuptools import find_packages, setup

from pretix_keycloak_create_user import __version__


try:
    with open(
        os.path.join(os.path.dirname(__file__), "README.md"), encoding="utf-8"
    ) as f:
        long_description = f.read()
except Exception:
    long_description = ""


class CustomBuild(build):
    def run(self):
        management.call_command("compilemessages", verbosity=1)
        build.run(self)


cmdclass = {"build": CustomBuild}


setup(
    name="pretix-keycloak-create-user",
    version=__version__,
    description="Invite Pretix participants to a Keycloak realm.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.fachschaften.org/tudo-fsinfo/admin/pretix-keycloak-create-user",
    project_urls={
        "Changelog": "https://gitlab.fachschaften.org/tudo-fsinfo/admin/pretix-keycloak-create-user/-/blob/main/CHANGELOG.md",
        "Tracker": "https://gitlab.fachschaften.org/tudo-fsinfo/admin/pretix-keycloak-create-user/-/issues",
        "Pretix Marketplace": "https://marketplace.pretix.eu/products/pretix-keycloak-create-user/",
    },
    author="Fachschaft Informatik TU Dortmund",
    author_email="root@oh14.de",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
        "License :: OSI Approved :: MIT License",
        "Topic :: Communications :: Chat",
    ],
    install_requires=["requests"],
    packages=find_packages(exclude=["tests", "tests.*"]),
    include_package_data=True,
    cmdclass=cmdclass,
    entry_points="""
[pretix.plugin]
pretix_keycloak_create_user=pretix_keycloak_create_user:PretixPluginMeta
""",
)
